### rotate_geometry

Rotate a geometry by angle around origin.

- Tool: `rotate_geometry`

Parameters

- geometry (string, WKT)
- angle (number)
- origin (string, default "center")
- use_radians (boolean, default false)

Returns

- geometry (string, WKT), status, message
